package cx.ath.jbzdak.wyklad1.paint;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;


/**
 * Created by: Jacek Bzdak
 */
public class TwoLayerPaintComponent extends JFrame{

   private final PaintLayer paintLayer;
   private final JPanel imagePanel;

   public TwoLayerPaintComponent() throws HeadlessException {

      JLayeredPane layeredPane = new JLayeredPane();

      layeredPane.setLayout(null); //Ustawiamy na brak layouta --- ponieważ layout managery
      // z definicji nie pozwalają by komponenty się przekrywały!

      add(layeredPane); // Dodanie layeredPane do ramki

      imagePanel = new JPanel(); // Stworzenie panelu z obrazkiem
      imagePanel.setLocation(0, 0);

      layeredPane.add(imagePanel, null, 1);  // Dodajemy go do layeredPane z indexem 1 (czyli 'pod' indeksem 0)

      paintLayer = new PaintLayer(); // Stworzenie panelu na którym będą rysowane kropki
      paintLayer.setLocation(0, 0);

      layeredPane.add(paintLayer, null, 0); // Dodanie go 'nad' obrazkiem


      ImageIcon image = getImage();

      JLabel label = new JLabel(image);

      imagePanel.add(label);


      setDefaultCloseOperation(DISPOSE_ON_CLOSE);
      
      createMenu();

      Dimension size = this.getSize();
      imagePanel.setSize(size);
      paintLayer.setSize(size);

      this.addComponentListener(new ComponentAdapter() {
         @Override
         public void componentResized(ComponentEvent e) {
            Dimension size = TwoLayerPaintComponent.this.getSize();
            imagePanel.setSize(size);
            paintLayer.setSize(size);

         }
      });
   }


   
   void createMenu(){
      JMenuBar jMenuBar = new JMenuBar();

      JMenuItem jMenuItem = new JMenuItem("Dodaj kropki");
      
      jMenuItem.addActionListener(new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            for (int ii = 0; ii < 10; ii++){
               paintLayer.addRandomDot();
            }
         }
      });
      
      jMenuBar.add(jMenuItem);
      
      jMenuItem = new JMenuItem("Usuń kropki");
      
      jMenuItem.addActionListener(new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            paintLayer.removeDots();            
         }
      });

      jMenuBar.add(jMenuItem);
      
      setJMenuBar(jMenuBar);
   }
   
   public ImageIcon getImage(){
      URL resource = getClass().getResource("image.jpg");
      if (resource == null){
         throw  new IllegalStateException();
      }
      return new ImageIcon(resource);
   }


   public static void main(String[] args) throws Exception{
      SwingUtilities.invokeLater(new Runnable() {
         public void run() {
            TwoLayerPaintComponent tf = new TwoLayerPaintComponent();
            tf.setSize(640, 480);
            tf.setVisible(true);
         }
      });
   }
}


class Dot{
   public int x, y, radius;  
}

class PaintLayer extends JPanel{
   
   List<Dot> dotList = new ArrayList<Dot>();

   Random random = new Random();

   PaintLayer() {
      setOpaque(true);
      setBackground(null);
   }

   public void removeDots(){
      dotList.clear();
      this.repaint();
   }
   
   public void addRandomDot(){
      Dot dot = new Dot();
      dot.x = random.nextInt((int) getSize().getWidth());
      dot.y = random.nextInt((int) getSize().getHeight());
      dot.radius = random.nextInt(30);
      dotList.add(dot);
      this.repaint();           
   }

   @Override
   public void paint(Graphics g) {
      g.setColor(Color.RED);
      for (Dot dot : dotList){
         g.drawOval(dot.x, dot.y, dot.radius, dot.radius);
         g.fillOval(dot.x, dot.y, dot.radius, dot.radius);
      }
   }

}
