package laboratoria.lab3.lookandfeel;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * Created by: Jacek Bzdak
 */
public class LookAndFeelChooser extends JFrame{
   
   static final Map<String, String> LF_MAP = createLfMap(); 

   static Map<String, String> createLfMap(){
      Map<String, String> map = new HashMap<String, String>();

      for (UIManager.LookAndFeelInfo info : UIManager.getInstalledLookAndFeels()){
         map.put(info.getName(), info.getClassName()); 
      }

      return Collections.unmodifiableMap(map);            
   }

   public LookAndFeelChooser() throws HeadlessException {
      
      JPanel chooseLFPanel = new JPanel();
      chooseLFPanel.setLayout(new FlowLayout());
      
      final JComboBox chooseLFComboBox = new JComboBox();

      for (String name : LF_MAP.keySet()){
         chooseLFComboBox.addItem(name);
      }

      chooseLFComboBox.setSelectedItem(UIManager.getLookAndFeel().getName());
      
      chooseLFComboBox.addActionListener(new ActionListener() {
         public void actionPerformed(ActionEvent e) {
            try{
               UIManager.setLookAndFeel(LF_MAP.get(chooseLFComboBox.getSelectedItem()));
               SwingUtilities.updateComponentTreeUI(LookAndFeelChooser.this);
               LookAndFeelChooser.this.pack();;
            }catch (Exception e1){
               e1.printStackTrace();
               JOptionPane.showMessageDialog(LookAndFeelChooser.this, "Błąd podczas zmiany LF");
            }
         }
      });

      add(chooseLFComboBox, BorderLayout.NORTH);

      JPanel componentPanel = new JPanel();


      componentPanel.add(new JButton("JButton"));
      componentPanel.add(new JTextField("JTextField"));
      componentPanel.add(new JCheckBox("JCheckBox"));
      componentPanel.add(new JRadioButton("JRadioButton"));
      componentPanel.add(new JLabel("JLabel"));
      componentPanel.add(new JList(new String[]{"JList, poz. 1", "JList, poz. 2", "JList, poz. 3"}));
      componentPanel.add(new JScrollBar(SwingConstants.HORIZONTAL));
      
      add(componentPanel);
   }

   public static void main(String[] args) throws Exception{
      SwingUtilities.invokeLater(new Runnable() {
         public void run() {
            LookAndFeelChooser chooser = new LookAndFeelChooser();
            chooser.setSize(640, 480);
            chooser.setVisible(true);
         }
      });
   }

}
